@@ -1,6 +1,7 @@
 from typing import Dict, Any
 
 from pyspark.sql import SparkSession, DataFrame
+from pyspark.sql.types import StructType
 
 
 class SparkDataFrameHelpers:
@@ -13,3 +14,12 @@ class SparkDataFrameHelpers:
         df = spark_session.createDataFrame(data=data, schema=schema)
         df.createOrReplaceTempView(name=view)
         return df
+
+    @staticmethod
+    def create_empty_dataframe(spark_session: SparkSession) -> DataFrame:
+        schema = StructType([])
+
+        df: DataFrame = spark_session.createDataFrame(
+            spark_session.sparkContext.emptyRDD(), schema)
+
+        return df
